diff mbox

[v4,1/6] hw/arm/boot: load_dtb becomes non static arm_load_dtb

Message ID 1414763612-4939-2-git-send-email-eric.auger@linaro.org
State New
Headers show

Commit Message

Auger Eric Oct. 31, 2014, 1:53 p.m. UTC
load_dtb is renamed into arm_load_dtb and becomes non static.
it will be used by machvirt for dynamic instantiation of
platform devices

Signed-off-by: Eric Auger <eric.auger@linaro.org>

---

v2 -> v3:
load_dtb renamed into arm_load_dtb

Conflicts:
	hw/arm/boot.c
---
 hw/arm/boot.c        | 12 ++++++------
 include/hw/arm/arm.h |  2 ++
 2 files changed, 8 insertions(+), 6 deletions(-)

Comments

Auger Eric Nov. 27, 2014, 9:19 a.m. UTC | #1
On 11/27/2014 10:00 AM, Shannon Zhao wrote:
> Hi Eric,
> 
> On 2014/10/31 21:53, Eric Auger wrote:
>> load_dtb is renamed into arm_load_dtb and becomes non static.
>> it will be used by machvirt for dynamic instantiation of
>> platform devices
>>
>> Signed-off-by: Eric Auger <eric.auger@linaro.org>
>>
>> ---
>>
>> v2 -> v3:
>> load_dtb renamed into arm_load_dtb
>>
>> Conflicts:
>> 	hw/arm/boot.c
>> ---
>>  hw/arm/boot.c        | 12 ++++++------
>>  include/hw/arm/arm.h |  2 ++
>>  2 files changed, 8 insertions(+), 6 deletions(-)
>>
>> diff --git a/hw/arm/boot.c b/hw/arm/boot.c
>> index bffbea5..f5714ea 100644
>> --- a/hw/arm/boot.c
>> +++ b/hw/arm/boot.c
>> @@ -313,7 +313,7 @@ static void set_kernel_args_old(const struct arm_boot_info *info)
>>  }
>>  
>>  /**
>> - * load_dtb() - load a device tree binary image into memory
>> + * arm_load_dtb() - load a device tree binary image into memory
>>   * @addr:       the address to load the image at
>>   * @binfo:      struct describing the boot environment
>>   * @addr_limit: upper limit of the available memory area at @addr
>> @@ -330,8 +330,8 @@ static void set_kernel_args_old(const struct arm_boot_info *info)
>>   *          0 if the image size exceeds the limit,
>>   *          -1 on errors.
>>   */
>> -static int load_dtb(hwaddr addr, const struct arm_boot_info *binfo,
>> -                    hwaddr addr_limit)
>> +int arm_load_dtb(hwaddr addr, const struct arm_boot_info *binfo,
>> +                 hwaddr addr_limit)
>>  {
>>      void *fdt = NULL;
>>      int size, rc;
>> @@ -504,7 +504,7 @@ void arm_load_kernel(ARMCPU *cpu, struct arm_boot_info *info)
>>              /* If we have a device tree blob, but no kernel to supply it to,
>>               * copy it to the base of RAM for a bootloader to pick up.
>>               */
>> -            if (load_dtb(info->loader_start, info, 0) < 0) {
>> +            if (arm_load_dtb(info->loader_start, info, 0) < 0) {
>>                  exit(1);
>>              }
>>          }
>> @@ -572,7 +572,7 @@ void arm_load_kernel(ARMCPU *cpu, struct arm_boot_info *info)
>>              if (elf_low_addr < info->loader_start) {
>>                  elf_low_addr = 0;
>>              }
>> -            if (load_dtb(info->loader_start, info, elf_low_addr) < 0) {
>> +            if (arm_load_dtb(info->loader_start, info, elf_low_addr) < 0) {
>>                  exit(1);
>>              }
>>          }
> 
> There is a "load_dtb" which is not updated.
Hi Shannon,

you mean in below comment, right?

Thanks

Eric
> 
>             /* Pass elf_low_addr as address limit to load_dtb if it may be
>              * pointing into RAM, otherwise pass '0' (no limit)
>              */
> 
> Thanks,
> Shannon
> 
>
Auger Eric Nov. 27, 2014, 10:29 a.m. UTC | #2
On 11/27/2014 11:17 AM, Shannon Zhao wrote:
> On 2014/11/27 17:19, Eric Auger wrote:
>> On 11/27/2014 10:00 AM, Shannon Zhao wrote:
>>> Hi Eric,
>>>
>>> On 2014/10/31 21:53, Eric Auger wrote:
>>>> load_dtb is renamed into arm_load_dtb and becomes non static.
>>>> it will be used by machvirt for dynamic instantiation of
>>>> platform devices
>>>>
>>>> Signed-off-by: Eric Auger <eric.auger@linaro.org>
>>>>
>>>> ---
>>>>
>>>> v2 -> v3:
>>>> load_dtb renamed into arm_load_dtb
>>>>
>>>> Conflicts:
>>>> 	hw/arm/boot.c
>>>> ---
>>>>  hw/arm/boot.c        | 12 ++++++------
>>>>  include/hw/arm/arm.h |  2 ++
>>>>  2 files changed, 8 insertions(+), 6 deletions(-)
>>>>
>>>> diff --git a/hw/arm/boot.c b/hw/arm/boot.c
>>>> index bffbea5..f5714ea 100644
>>>> --- a/hw/arm/boot.c
>>>> +++ b/hw/arm/boot.c
>>>> @@ -313,7 +313,7 @@ static void set_kernel_args_old(const struct arm_boot_info *info)
>>>>  }
>>>>  
>>>>  /**
>>>> - * load_dtb() - load a device tree binary image into memory
>>>> + * arm_load_dtb() - load a device tree binary image into memory
>>>>   * @addr:       the address to load the image at
>>>>   * @binfo:      struct describing the boot environment
>>>>   * @addr_limit: upper limit of the available memory area at @addr
>>>> @@ -330,8 +330,8 @@ static void set_kernel_args_old(const struct arm_boot_info *info)
>>>>   *          0 if the image size exceeds the limit,
>>>>   *          -1 on errors.
>>>>   */
>>>> -static int load_dtb(hwaddr addr, const struct arm_boot_info *binfo,
>>>> -                    hwaddr addr_limit)
>>>> +int arm_load_dtb(hwaddr addr, const struct arm_boot_info *binfo,
>>>> +                 hwaddr addr_limit)
>>>>  {
>>>>      void *fdt = NULL;
>>>>      int size, rc;
>>>> @@ -504,7 +504,7 @@ void arm_load_kernel(ARMCPU *cpu, struct arm_boot_info *info)
>>>>              /* If we have a device tree blob, but no kernel to supply it to,
>>>>               * copy it to the base of RAM for a bootloader to pick up.
>>>>               */
>>>> -            if (load_dtb(info->loader_start, info, 0) < 0) {
>>>> +            if (arm_load_dtb(info->loader_start, info, 0) < 0) {
>>>>                  exit(1);
>>>>              }
>>>>          }
>>>> @@ -572,7 +572,7 @@ void arm_load_kernel(ARMCPU *cpu, struct arm_boot_info *info)
>>>>              if (elf_low_addr < info->loader_start) {
>>>>                  elf_low_addr = 0;
>>>>              }
>>>> -            if (load_dtb(info->loader_start, info, elf_low_addr) < 0) {
>>>> +            if (arm_load_dtb(info->loader_start, info, elf_low_addr) < 0) {
>>>>                  exit(1);
>>>>              }
>>>>          }
>>>
>>> There is a "load_dtb" which is not updated.
>> Hi Shannon,
>>
>> you mean in below comment, right?

OK thanks for your time.

I will correct

Best Regards

Eric
>>
> 
> Yes:-)
> 
>> Thanks
>>
>> Eric
>>>
>>>             /* Pass elf_low_addr as address limit to load_dtb if it may be
>>>              * pointing into RAM, otherwise pass '0' (no limit)
>>>              */
>>>
>>> Thanks,
>>> Shannon
>>>
>>>
>>
>>
>> .
>>
> 
>
diff --git a/include/hw/arm/arm.h b/include/hw/arm/arm.h
index cefc9e6..5fdae7b 100644
--- a/include/hw/arm/arm.h
+++ b/include/hw/arm/arm.h
@@ -68,6 +68,8 @@  struct arm_boot_info {
     hwaddr entry;
 };
 void arm_load_kernel(ARMCPU *cpu, struct arm_boot_info *info);
+int arm_load_dtb(hwaddr addr, const struct arm_boot_info *binfo,
+                 hwaddr addr_limit);
 
 /* Multiplication factor to convert from system clock ticks to qemu timer
    ticks.  */
diff mbox

Patch

diff --git a/hw/arm/boot.c b/hw/arm/boot.c
index bffbea5..f5714ea 100644
--- a/hw/arm/boot.c
+++ b/hw/arm/boot.c
@@ -313,7 +313,7 @@  static void set_kernel_args_old(const struct arm_boot_info *info)
 }
 
 /**
  * load_dtb() - load a device tree binary image into memory
  * @addr:       the address to load the image at
  * @binfo:      struct describing the boot environment
  * @addr_limit: upper limit of the available memory area at @addr
@@ -330,8 +330,8 @@  static void set_kernel_args_old(const struct arm_boot_info *info)
  *          0 if the image size exceeds the limit,
  *          -1 on errors.
  */
-static int load_dtb(hwaddr addr, const struct arm_boot_info *binfo,
-                    hwaddr addr_limit)
+int arm_load_dtb(hwaddr addr, const struct arm_boot_info *binfo,
+                 hwaddr addr_limit)
 {
     void *fdt = NULL;
     int size, rc;
@@ -504,7 +504,7 @@  void arm_load_kernel(ARMCPU *cpu, struct arm_boot_info *info)
             /* If we have a device tree blob, but no kernel to supply it to,
              * copy it to the base of RAM for a bootloader to pick up.
              */
-            if (load_dtb(info->loader_start, info, 0) < 0) {
+            if (arm_load_dtb(info->loader_start, info, 0) < 0) {
                 exit(1);
             }
         }
@@ -572,7 +572,7 @@  void arm_load_kernel(ARMCPU *cpu, struct arm_boot_info *info)
             if (elf_low_addr < info->loader_start) {
                 elf_low_addr = 0;
             }
-            if (load_dtb(info->loader_start, info, elf_low_addr) < 0) {
+            if (arm_load_dtb(info->loader_start, info, elf_low_addr) < 0) {
                 exit(1);
             }
         }
@@ -637,7 +637,7 @@  void arm_load_kernel(ARMCPU *cpu, struct arm_boot_info *info)
              */
             hwaddr dtb_start = QEMU_ALIGN_UP(info->initrd_start + initrd_size,
                                              4096);
-            if (load_dtb(dtb_start, info, 0) < 0) {
+            if (arm_load_dtb(dtb_start, info, 0) < 0) {
                 exit(1);
             }
             fixupcontext[FIXUP_ARGPTR] = dtb_start;
@@ -313,7 +313,7 @@  static void set_kernel_args_old(const struct arm_boot_info *info)
 
 /**
- * load_dtb() - load a device tree binary image into memory
+ * arm_load_dtb() - load a device tree binary image into memory
  * @addr:       the address to load the image at
  * @binfo:      struct describing the boot environment